@@ -1,39 +1,27 @@
 /*
- *   Copyright (C) 2000 Matthias Elter <elter@kde.org>
- *   Copyright (C) 2008 Laurent Montel <montel@kde.org>
+ *   SPDX-FileCopyrightText: 2000 Matthias Elter <elter@kde.org>
+ *   SPDX-FileCopyrightText: 2008 Laurent Montel <montel@kde.org>
  *
- *   This program is free software; you can redistribute it and/or modify
- *   it under the terms of the GNU General Public License as published by
- *   the Free Software Foundation; either version 2 of the License, or
- *   (at your option) any later version.
- *
- *   This program is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU General Public License for more details.
- *
- *   You should have received a copy of the GNU General Public License
- *   along with this program; if not, write to the Free Software
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+ *   SPDX-License-Identifier: GPL-2.0-or-later
  *
  */
 
 #include "basictab.h"
 
 #include <QCheckBox>
-#include <QLabel>
-#include <QGroupBox>
-#include <QVBoxLayout>
 #include <QGridLayout>
+#include <QGroupBox>
+#include <QLabel>
+#include <QVBoxLayout>
 
 #include <KConfigGroup>
-#include <KLocalizedString>
-#include <KKeySequenceWidget>
-#include <QLineEdit>
-#include <KIconButton>
 #include <KDesktopFile>
-#include <KUrlRequester>
+#include <KIconButton>
+#include <KKeySequenceWidget>
+#include <KLocalizedString>
 #include <KShell>
+#include <KUrlRequester>
+#include <QLineEdit>
 
 #include "globalaccel.h"
 
@@ -87,18 +75,18 @@ void BasicTab::initGeneralTab()
     generalTabLayout->addWidget(_execLabel, 3, 0);
     _execEdit = new KUrlRequester();
     _execEdit->lineEdit()->setAcceptDrops(false);
-    _execEdit->setWhatsThis(i18n(
-                                "Following the command, you can have several place holders which will be replaced "
-                                "with the actual values when the actual program is run:\n"
-                                "%f - a single file name\n"
-                                "%F - a list of files; use for applications that can open several local files at once\n"
-                                "%u - a single URL\n"
-                                "%U - a list of URLs\n"
-                                "%d - the folder of the file to open\n"
-                                "%D - a list of folders\n"
-                                "%i - the icon\n"
-                                "%m - the mini-icon\n"
-                                "%c - the caption"));
+    _execEdit->setWhatsThis(
+        i18n("Following the command, you can have several place holders which will be replaced "
+             "with the actual values when the actual program is run:\n"
+             "%f - a single file name\n"
+             "%F - a list of files; use for applications that can open several local files at once\n"
+             "%u - a single URL\n"
+             "%U - a list of URLs\n"
+             "%d - the folder of the file to open\n"
+             "%D - a list of folders\n"
+             "%i - the icon\n"
+             "%m - the mini-icon\n"
+             "%c - the caption"));
     _execLabel->setBuddy(_execEdit);
     generalTabLayout->addWidget(_execEdit, 3, 1, 1, 2);
 
@@ -107,7 +95,7 @@ void BasicTab::initGeneralTab()
     generalTabLayout->addWidget(_launchCB, 4, 0, 1, 3);
 
     // KDE visibility
-    _onlyShowInKdeCB = new QCheckBox(i18n("Only show in KDE"));
+    _onlyShowInKdeCB = new QCheckBox(i18n("Only show when logged into a Plasma session"));
     generalTabLayout->addWidget(_onlyShowInKdeCB, 5, 0, 1, 3);
 
     // hidden entry
@@ -223,8 +211,8 @@ void BasicTab::initConnections()
 
 void BasicTab::slotDisableAction()
 {
-    //disable all group at the beginning.
-    //because there is not file selected.
+    // disable all group at the beginning.
+    // because there is not file selected.
     _nameEdit->setEnabled(false);
     _descriptionEdit->setEnabled(false);
     _commentEdit->setEnabled(false);
@@ -359,7 +347,8 @@ void BasicTab::setEntryInfo(MenuEntryInfo *entryInfo)
         _launchCB->setChecked(df->desktopGroup().readEntry("X-KDE-StartupNotify", true));
     }
 
-    _onlyShowInKdeCB->setChecked(df->desktopGroup().readXdgListEntry("OnlyShowIn").contains(QLatin1String("KDE")));     // or maybe enable only if it contains nothing but KDE?
+    // or maybe enable only if it contains nothing but KDE?
+    _onlyShowInKdeCB->setChecked(df->desktopGroup().readXdgListEntry("OnlyShowIn").contains(QLatin1String("KDE")));
 
     if (df->desktopGroup().hasKey("NoDisplay")) {
         _hiddenEntryCB->setChecked(df->desktopGroup().readEntry("NoDisplay", true));
@@ -408,7 +397,7 @@ void BasicTab::apply()
 
         QStringList onlyShowIn = df->desktopGroup().readXdgListEntry("OnlyShowIn");
         /* the exact semantics of this checkbox are unclear if there is more than just KDE in the list...
-         * For example: - The list is "Gnome;", the user enables "Only show in KDE" - should we remove Gnome?
+         * For example: - The list is "Gnome;", the user enables "Only show when logged into a Plasma session" - should we remove Gnome?
          *              - The list is "Gnome;KDE;", the user unchecks the box - should we keep Gnome?
          */
         if (_onlyShowInKdeCB->isChecked() && !onlyShowIn.contains(QLatin1String("KDE"))) {
